Documentation
¶
Index ¶
- func CloneRepo(clonePath, repoURL string) error
- func ConvertGitHubURL(URL string) (string, error)
- func CurlEndpoint(endpoint string) ([]byte, error)
- func DownloadDevfile(dir string) ([]byte, error)
- func IsExist(path string) (bool, error)
- func ReadDevfilesFromRepo(localpath string, depth int) (map[string][]byte, error)
- func SanitizeName(name string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConvertGitHubURL ¶
ConvertGitHubURL converts a git url to its raw format adapted from https://github.com/redhat-developer/odo/blob/e63773cc156ade6174a533535cbaa0c79506ffdb/pkg/catalog/catalog.go#L72
func CurlEndpoint ¶
CurlEndpoint curls the endpoint and returns the response or an error if the response is a non-200 status
func DownloadDevfile ¶
DownloadDevfile downloads devfile from the various possible devfile locations in dir and returns the contents
func ReadDevfilesFromRepo ¶
ReadDevfilesFromRepo attempts to read and return devfiles from the local path upto the specified depth
func SanitizeName ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.